;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; GNU GENERAL PUBLIC LICENSE ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; percolation is a percolation model of the product lifecycle
;;
;; Copyright (C) 2014 Paolo Zeppini & Koen Frenken & Luis R. Izquierdo
;;
;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License
;; as published by the Free Software Foundation; either version 3
;; of the License, or (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
;;
;; Contact information:
;; Paolo Zeppini
;; e-mail: paolo.zeppini@gmail.com


;;;;;;;;;;;;;;;;;
;;; VARIABLES ;;;
;;;;;;;;;;;;;;;;;

globals [
  entropy
  would-buys
  avg-accessibility ;; average number of buyers reachable by each buyer in an infinite number of steps
  clustering-coefficient
]

;;;;;;;;;;;;;;
;;; BREEDS ;;;
;;;;;;;;;;;;;;

breed [consumers consumer]
breed [products product]

consumers-own [
  reservation-price
  product-bought
  product-bought-in-previous-time-step?
  attention-list
  list-of-potentials
  node-clustering-coefficient
  nbrs-in-radius-1
  tmp-nbrs
]

products-own [
  price
  rank
  n-of-adopters
  share
]

;;;;;;;;;;;;;;;;;;;
;;; MODEL SETUP ;;;
;;;;;;;;;;;;;;;;;;;

to startup
  clear-all
  no-display

  setup-consumers
  setup-products
  build-initial-network

  if n-of-initial-offers > floor (n-of-consumers / n-of-products) [
    set n-of-initial-offers (floor (n-of-consumers / n-of-products))
  ]

  foreach (shuffle sort products) [ ?1 ->
    let prod ?1
    ask n-of n-of-initial-offers (consumers with [product-bought = 0]) [
      ifelse give-it-for-free? [buy-product prod] [consider-buying-product prod]
    ]
  ]
  reset-ticks
  with-local-randomness [update-graphs]
  display
end

to setup-consumers
  set-default-shape consumers "circle"
  create-ordered-consumers n-of-consumers [
    let x random-gamma alphad 1
    set reservation-price ( x / ( x + random-gamma betad 1) ) ; reservation-price ~ Beta(alphad,betad) in [0,1]. Case alphad = betad = 1 is uniform distribution
    set product-bought-in-previous-time-step? false
    fd 30
    set size 1
    set color blue
  ]
end

to setup-products
  let rank-counter 1
  create-products n-of-products [
    set price initial-price
    set share 0
    set rank rank-counter
    set rank-counter (rank-counter + 1)
    set color (rank * 60 - 5)
    set hidden? true
  ]
end

;;;;;;;;;;;;;;;;;;;;;;
;;; MAIN PROCEDURE ;;;
;;;;;;;;;;;;;;;;;;;;;;

to go
  ask consumers [ set attention-list [] ]

  ifelse attention-list-mode = "products just bought only" [
    ask (consumers with [product-bought-in-previous-time-step?]) [
      ask link-neighbors [set attention-list (fput ([product-bought] of myself) attention-list)]
      set product-bought-in-previous-time-step? false
    ]
  ][
  ifelse attention-list-mode = "all - select randomly" [
    ask (consumers with [product-bought-in-previous-time-step?]) [
      ask link-neighbors [set attention-list remove 0 ([product-bought] of link-neighbors)]
      ;; here there must be at least one consumer who has bought the product
      ;; (the one who is asking all this), so we don't have any issues with "nobody"
      set product-bought-in-previous-time-step? false
    ]
  ][
  if attention-list-mode = "all - select highest" [
    ask (consumers with [product-bought-in-previous-time-step?]) [
      ask link-neighbors [
        let products-bought-by-nbrs (turtle-set remove 0 ([product-bought] of link-neighbors))
        ;; here there must be at least one consumer who has bought the product
        ;; (the one who is asking all this), so we don't have any issues with "nobody"
        set attention-list (list max-one-of products-bought-by-nbrs [price])
      ]
      set product-bought-in-previous-time-step? false
    ]
  ]
  ]]

  ask (consumers with [(product-bought = 0) and (not empty? attention-list)])
    [check-attention-list]

  ask (consumers with [product-bought = 0])
    [
    if random-float 1.0 < prob-exogenous-buy [consider-buying-product one-of products]
    ]

  ask products [update-price]
  tick
  with-local-randomness [update-graphs]

  if ticks = time-horizon [stop]
  if not any? (consumers with [product-bought-in-previous-time-step?]) [stop]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; CONSUMERS' PROCEDURES ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to check-attention-list
  ;; here there is at least one item in the attention-list
  if (length attention-list > 1)
    [set attention-list shuffle attention-list]
  foreach attention-list [ ?1 ->
    if (product-bought = 0) [consider-prod ?1]
  ]
end

to consider-prod [prod]
  let rank-of-product ([rank] of prod)

  set list-of-potentials sort (products with [(rank >= (rank-of-product - tau)) and (rank <= (rank-of-product + tau))])
  set list-of-potentials filter [ ?1 -> [price] of ?1 <= reservation-price ] list-of-potentials
  if (not empty? list-of-potentials) [
    buy-one-product-from-list-of-potentials rank-of-product
  ]
end

to buy-one-product-from-list-of-potentials [original-rank]
  ;; the list cannot be empty here
  ifelse (length list-of-potentials = 1)
    [
      buy-product (first list-of-potentials)
    ]
    [ ;; there's more than one potential
      let list-of-indicators (map [ ?1 -> beta ^ (abs (original-rank - ([rank] of ?1))) ] list-of-potentials)
      let cum-indicators [0]
      ;; cum-indicators last value is 0
      foreach list-of-indicators [ ?1 -> set cum-indicators fput (?1 + first cum-indicators) cum-indicators ]
      let tmp (random-float first cum-indicators)
      ;; select the product to buy with probability proportional to its indicator
      let product-number ((length list-of-indicators) - 1)
      foreach butfirst cum-indicators [ ?1 -> if ( tmp < ?1) [set product-number (product-number - 1)] ]
      buy-product (item product-number list-of-potentials)
      ;show list-of-potentials
      ;show list-of-indicators
      ;show product-number
    ]
end

to buy-product [prod]
  set product-bought prod
  set product-bought-in-previous-time-step? true
  ask prod [ set n-of-adopters (n-of-adopters + 1) ]
end

to update-color
  set color ([color] of product-bought)
end

  ;; resize-consumers, change back and forth from size based on degree to a size of 1
to resize-consumers
  ifelse ( not (any? consumers with [size > 1]) )
  [ ask consumers [ set size sqrt count link-neighbors] ]
  [ ask consumers [ set size 1 ] ]
end

to consider-buying-product [prod]
  if ([price] of prod <= reservation-price) [
    buy-product prod
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; PRODUCTS' PROCEDURES ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to update-price
  if n-of-adopters > 1 [
    set price (initial-price * (n-of-adopters ^ (- learning-coefficient)))
  ]
end


to update-shares
  let n-of-adopters-list ([n-of-adopters] of products)
  let total-adopters (sum n-of-adopters-list)
  if (total-adopters != 0) [
    set share n-of-adopters-list / total-adopters
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; GRAPHS AND DATA GATHERING ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to update-graphs
  ask (consumers with [product-bought-in-previous-time-step?]) [update-color]
  ;; comment for batch simulations
  do-plots
end


to plot-accessibility
  let steps accessibility-steps
  if accessibility-steps = "Infinity" [set steps n-of-consumers]
  let accessibility-list [accessibility steps] of consumers
  let max-accessibility max accessibility-list
  set-current-plot "Accessibility Distribution"
  set-plot-x-range 0 (max-accessibility + 1)  ;; + 1 to make room for the width of the last bar
  histogram accessibility-list
  set avg-accessibility mean accessibility-list
end

to do-plots
  plot-adopters-time-series
  plot-agents-per-product
  plot-entropy
  ;;  plot-share
  plot-shares
  plot-would-buys
  plot-price-time-series
  plot-total-adopters
end

to plot-adopters-time-series
  set-current-plot "adopters"
  foreach sort products [ ?1 ->
    set-current-plot-pen (word [rank] of ?1)
    plot ([n-of-adopters] of ?1)
  ]
end

to plot-price-time-series
  set-current-plot "prices"
  foreach sort products [ ?1 ->
    set-current-plot-pen (word [rank] of ?1)
    plot ([price] of ?1)
  ]
end

to calculate-entropy
  let n-of-adopters-list remove 0 ([n-of-adopters] of products)
  let total-adopters (sum n-of-adopters-list)
  if (total-adopters != 0) [
    set entropy ((log total-adopters 2) - (sum map [ ?1 -> ?1 * (log ?1 2) ] n-of-adopters-list) / total-adopters)
  ]
end

to plot-entropy
  calculate-entropy
  set-current-plot "entropy"
  plot entropy
end

to plot-total-adopters
  let n-of-adopters-list remove 0 ([n-of-adopters] of products)
  let total-adopters (sum n-of-adopters-list)
  set-current-plot "overall-adopters"
  plot total-adopters
end

;to calculate-share
;  let n-of-adopters-list remove 0 ([n-of-adopters] of products)
;  let total-adopters (sum n-of-adopters-list)
;  if (total-adopters != 0) [
;    set share n-of-adopters-list / total-adopters
;  ]
;end

;to plot-share
;  calculate-share
;  set-current-plot "share"
;  plot share
;end

to plot-shares
  let n-of-adopters-list ([n-of-adopters] of products)
  let total-adopters (sum n-of-adopters-list)
  set-current-plot "share"
  foreach sort products [ ?1 ->
    set-current-plot-pen (word [rank] of ?1)
    plot ([n-of-adopters / total-adopters] of ?1)
  ]
end

; --- trying to build a share vector time series, histogram, etc
;
; show sort-by [?1 < ?2] (map [precision (? /  max ([n-of-adopters] of products)) 2] [n-of-adopters] of products)
;
; show (map [(list ?1 ?2)] ([n-of-adopters] of products) ([rank] of products))
;
; show sort-by [last ?1 < last ?2] (map [(list ?1 ?2)] ([n-of-adopters] of products) ([rank] of products))


to plot-agents-per-product
  let n-of-adopters-list ([n-of-adopters] of products)
  let max-n-of-adopters (max n-of-adopters-list)
  set-current-plot "Agents per product"
  clear-plot
  set-plot-x-range 0 (n-of-products)
  set-plot-y-range 0 (max-n-of-adopters)
  let prod-counter (length [n-of-adopters] of products - 1)
  foreach [n-of-adopters] of products [ ?1 ->
    plotxy prod-counter ?1
    set prod-counter (prod-counter - 1)
  ]
end

to plot-would-buys
  let min-price min [price] of products
  set would-buys (count consumers with [(product-bought = 0) and (min-price <= reservation-price)])
  set-current-plot "would-buys"
  plot would-buys
end


;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; NETWORK OPERATIONS ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;

to build-initial-network
  if network-structure = "random"
    [ build-random-network]
  if network-structure = "preferential attachment"
    [ build-preferential-attachment-network pref-attachment-links]
  if network-structure = "ring"
    [ build-ring-network]
  if network-structure = "star"
    [ build-star-network]
  if network-structure = "grid 4 nbrs" or network-structure = "grid 8 nbrs"
    [ build-grid-network]
  if network-structure = "Watts-Strogatz"
    [build-w-s-network]

  set num-links count links
;;  plot-accessibility  ;; comment if network is big unless you look at these variables
;;  find-clustering-coefficient
end

to build-random-network
 let list-of-consumers (sort consumers)
   ;; you cannot create more undirected links than (n-of-consumers * (n-of-consumers - 1) / 2)
 set num-links min list num-links (n-of-consumers * (n-of-consumers - 1) / 2)
 if-else num-links < (0.72 * (n-of-consumers * (n-of-consumers - 1) / 2))
   [ repeat num-links [add-random-link] ]
   [
     ;; make a fully connected network
     let tmp-list-of-consumers list-of-consumers
     ;; this creates a list where consumers are sorted in ascending order by who number
     foreach list-of-consumers [
       let first-consumer first tmp-list-of-consumers
       set tmp-list-of-consumers but-first tmp-list-of-consumers
       ask first-consumer [foreach tmp-list-of-consumers [ ??1 -> create-link-with ??1 ]]
     ]

     ;; and randomly delete the necessary links
     ask n-of ((n-of-consumers * (n-of-consumers - 1) / 2) - num-links) links [die]
   ]
end

to build-preferential-attachment-network [n-of-edges-per-new-vertex]
  ;; This is Barabasi and Albert's "preferential attachment" model of network growth (See Newman,
  ;; "The structure and function of complex networks", sec. 7B). Basically, each new consumer selects
  ;; "pref-attachment-links" other consumers to link to, who are selected with probability proportional to
  ;; their number of existing links.

  let vertices shuffle sort consumers

  if n-of-edges-per-new-vertex > 0 [

  ask (first vertices) [create-link-with (item 1 vertices)]
  let list-of-vertices-repeated list 0 1
  let n-of-vertices-in-the-network 2

  repeat (length vertices) - n-of-vertices-in-the-network [
    let vertices-linked []
    while [(length vertices-linked < n-of-edges-per-new-vertex)
          and (length vertices-linked < n-of-vertices-in-the-network)] [
      let vertex-to-link one-of list-of-vertices-repeated
      if not member? vertex-to-link vertices-linked [
        set vertices-linked fput vertex-to-link vertices-linked
      ]
    ]

    ;; now link the vertices
    ask (item n-of-vertices-in-the-network vertices)
      [foreach vertices-linked [ ?1 -> create-link-with item ?1 vertices ]]

    ;; and update list-of-vertices-repeated
    set list-of-vertices-repeated sentence list-of-vertices-repeated vertices-linked
    repeat (length vertices-linked) [
      set list-of-vertices-repeated fput n-of-vertices-in-the-network list-of-vertices-repeated
    ]

    set n-of-vertices-in-the-network (n-of-vertices-in-the-network + 1)
  ]

  ]
end

to build-star-network
  ;; one consumer is randomly chosen. She links to all the others.
  ask one-of consumers [create-links-with other consumers]
end

to build-grid-network
  let consumers-per-line (ceiling sqrt n-of-consumers)
  let gap (min (list world-height world-width)) / consumers-per-line
  ask consumers [
    setxy ((who mod consumers-per-line) * gap + min-pxcor + gap / 2)
          (int (who / consumers-per-line) * gap + min-pycor + gap / 2)
  ]
  ask consumers [
    create-links-with other consumers
      in-radius (gap * ifelse-value (network-structure = "grid 4 nbrs") [1.4] [1.8])
    set nbrs-in-radius-1 link-neighbors
  ]
  repeat (grid-radius - 1) [
    ask consumers [set tmp-nbrs link-neighbors]
    ask consumers [
      create-links-with other turtle-set ([nbrs-in-radius-1] of tmp-nbrs)
    ]
  ]
end

to build-ring-network
  ;; first we build a regular lattice with mean degree mean-degree
  layout-circle (sort consumers) max-pxcor - 1
  set mean-degree 2 * (floor (mean-degree / 2))
  foreach n-values (mean-degree / 2) [ ?1 -> ?1 + 1 ]
  [ ?1 -> ask consumers [create-link-with consumer ( (who + ?1) mod n-of-consumers) ] ]

end

to build-w-s-network
 build-ring-network
 ask links [
   if (random-float 1.0) < p-rewiring
   [ let consumer1 end1
     ;; find a node different from itslef and any of its neighbours
     let consumer2 one-of consumers with [(self != consumer1) and (not link-neighbor? consumer1)]
     ask consumer1 [create-link-with consumer2]
     die
   ]
 ]
end

to add-random-link
  let node-1 one-of consumers
  let node-2 one-of consumers
  ask node-1 [
    ifelse link-neighbor? node-2 or node-1 = node-2
    [ add-random-link ]
    [ create-link-with node-2 ]
  ]
end

to-report accessibility [num-steps]
  let step 1
  let reachable-consumers link-neighbors
  let old-length 0
  let new-length count reachable-consumers
  while [ new-length != old-length and step < num-steps]
        [ set old-length new-length
          set reachable-consumers turtle-set
            remove-duplicates sort
              (turtle-set
                reachable-consumers
                [link-neighbors] of reachable-consumers)
          set new-length (count reachable-consumers)
          set step (step + 1)
        ]
  report new-length - ifelse-value (member? self reachable-consumers) [1] [0]
end

;; The following two procedures have been copied from the
;; NetLogo Small Worlds model, in NetLogo's library.
;; Copyright at the end of this page.

to-report in-neighborhood? [ hood ]
  report ( member? end1 hood and member? end2 hood )
end

to find-clustering-coefficient
  ifelse all? consumers [count link-neighbors <= 1]
  [
    ;; it is undefined
    set clustering-coefficient "undefined"
  ]
  [
    let total 0
    ask consumers with [ count link-neighbors <= 1]
      [ set node-clustering-coefficient "undefined" ]
    ask consumers with [ count link-neighbors > 1]
    [
      let hood link-neighbors
      set node-clustering-coefficient (2 * count links with [ in-neighborhood? hood ] /
                                         ((count hood) * (count hood - 1)) )
      ;; find the sum for the value at consumers
      set total total + node-clustering-coefficient
    ]
    ;; take the average
    set clustering-coefficient total / count consumers with [count link-neighbors > 1]
  ]
end

;;;;;;;;;;;;;;
;;; Layout ;;;
;;;;;;;;;;;;;;

to do-layout
  ;; the number 3 here is arbitrary; more repetitions slows down the
  ;; model, but too few gives poor layouts
  repeat 3 [
    ;; the more consumers we have to fit into the same amount of space,
    ;; the smaller the inputs to layout-spring we'll need to use
    let factor sqrt count consumers
    ;; numbers here are arbitrarily chosen for pleasing appearance
    layout-spring (consumers with [any? link-neighbors]) links (1 / factor) (7 / factor) (3 / factor)
    display  ;; for smooth animation
  ]
  ;; don't bump the edges of the world
  let x-offset max [xcor] of consumers + min [xcor] of consumers
  let y-offset max [ycor] of consumers + min [ycor] of consumers
  ;; big jumps look funny, so only adjust a little each time
  set x-offset limit-magnitude x-offset 0.1
  set y-offset limit-magnitude y-offset 0.1
  ask consumers [ setxy (xcor - x-offset / 2) (ycor - y-offset / 2) ]
end

to-report limit-magnitude [number limit]
  if number > limit [ report limit ]
  if number < (- limit) [ report (- limit) ]
  report number
end

to-report round-to-digits [number digits]
  let epsilon 0.0001
  if ((number >= (- epsilon)) and (number <= epsilon)) [report 0.0]
  let power-of-ten ((ceiling (log (abs number) 10)) - digits)
  if-else power-of-ten > 0
    ;; Be careful with round, as it returns an integer (very short range).
    [ report (round (number / (10.0 ^ power-of-ten))) * (10.0 ^ power-of-ten) ]
    [ report (round (number * (10.0 ^ (- power-of-ten)))) / (10.0 ^ (- power-of-ten)) ]
end
@#$#@#$#@
GRAPHICS-WINDOW
232
10
745
524
-1
-1
5.0
1
10
1
1
1
0
0
0
1
-50
50
-50
50
1
1
1
ticks
30.0

CHOOSER
7
520
210
565
network-structure
network-structure
"random" "preferential attachment" "star" "grid 4 nbrs" "grid 8 nbrs" "ring" "Watts-Strogatz"
6

SLIDER
7
602
201
635
pref-attachment-links
pref-attachment-links
0
100
1.0
1
1
NIL
HORIZONTAL

SLIDER
7
567
179
600
num-links
num-links
0
n-of-consumers * (n-of-consumers) / 2
200.0
1
1
NIL
HORIZONTAL

BUTTON
5
10
72
43
setup
startup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
76
10
139
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
144
10
227
43
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
5
101
220
134
n-of-consumers
n-of-consumers
0
10000
100.0
100
1
NIL
HORIZONTAL

PLOT
234
553
480
694
Accessibility Distribution
# of reachable players
# of players
0.0
2.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 false "" ""

CHOOSER
488
559
630
604
accessibility-steps
accessibility-steps
1 2 3 4 5 10 20 "Infinity"
0

BUTTON
488
608
631
641
Update accessibility
plot-accessibility
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
634
551
745
604
NIL
avg-accessibility
3
1
13

BUTTON
618
661
739
694
relax network
do-layout
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
6
390
207
423
initial-price
initial-price
0
1
0.5
0.05
1
NIL
HORIZONTAL

SLIDER
6
351
221
384
n-of-products
n-of-products
1
100
1.0
1
1
NIL
HORIZONTAL

BUTTON
491
661
616
694
NIL
resize-consumers
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
7
637
179
670
grid-radius
grid-radius
1
10
1.0
1
1
NIL
HORIZONTAL

MONITOR
635
606
744
659
clust. coeff.
clustering-coefficient
3
1
13

SLIDER
6
273
115
306
tau
tau
0
10
0.0
1
1
NIL
HORIZONTAL

SLIDER
6
311
178
344
beta
beta
0
1
2.0
0.01
1
NIL
HORIZONTAL

SLIDER
5
145
177
178
n-of-initial-offers
n-of-initial-offers
0
100
10.0
1
1
NIL
HORIZONTAL

SLIDER
7
430
179
463
learning-coefficient
learning-coefficient
0
1
0.0
0.01
1
NIL
HORIZONTAL

PLOT
757
12
957
162
adopters
time
#
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"1" 1.0 0 -7500403 true "" ""
"2" 1.0 0 -2674135 true "" ""
"3" 1.0 0 -955883 true "" ""
"4" 1.0 0 -6459832 true "" ""
"5" 1.0 0 -1184463 true "" ""
"6" 1.0 0 -10899396 true "" ""
"7" 1.0 0 -13840069 true "" ""
"8" 1.0 0 -14835848 true "" ""
"9" 1.0 0 -11221820 true "" ""
"10" 1.0 0 -13791810 true "" ""
"11" 1.0 0 -13345367 true "" ""
"12" 1.0 0 -8630108 true "" ""
"13" 1.0 0 -5825686 true "" ""
"14" 1.0 0 -2064490 true "" ""
"15" 1.0 0 -16777216 true "" ""
"20" 1.0 0 -16777216 true "" ""
"16" 1.0 0 -16777216 true "" ""
"17" 1.0 0 -16777216 true "" ""
"18" 1.0 0 -16777216 true "" ""
"19" 1.0 0 -16777216 true "" ""
"21" 1.0 0 -16777216 true "" ""

MONITOR
868
680
931
733
NIL
entropy
3
1
13

PLOT
758
314
958
464
entropy
NIL
NIL
0.0
10.0
3.0
3.5
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

CHOOSER
7
467
222
512
attention-list-mode
attention-list-mode
"products just bought only" "all - select randomly" "all - select highest"
0

SLIDER
5
182
193
215
prob-exogenous-buy
prob-exogenous-buy
0
1
0.0
0.01
1
NIL
HORIZONTAL

PLOT
758
466
958
616
would-buys
time
shares
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SWITCH
6
226
150
259
give-it-for-free?
give-it-for-free?
0
1
-1000

MONITOR
757
683
834
728
NIL
would-buys
0
1
11

MONITOR
759
632
822
677
adopters
count (consumers with [product-bought != 0])
0
1
11

MONITOR
868
631
956
676
non-adopters
count (consumers with [product-bought = 0])
17
1
11

SLIDER
5
58
177
91
time-horizon
time-horizon
0
10000
1000.0
100
1
NIL
HORIZONTAL

SLIDER
7
673
179
706
mean-degree
mean-degree
0
100
4.0
1
1
NIL
HORIZONTAL

SLIDER
7
708
179
741
p-rewiring
p-rewiring
0
1
0.1
0.001
1
NIL
HORIZONTAL

PLOT
963
318
1163
670
prices
time
NIL
0.0
10.0
0.2
0.5
true
true
"" ""
PENS
"1" 1.0 0 -7500403 true "" ""
"2" 1.0 0 -2674135 true "" ""
"3" 1.0 0 -955883 true "" ""
"4" 1.0 0 -6459832 true "" ""
"5" 1.0 0 -1184463 true "" ""
"6" 1.0 0 -10899396 true "" ""
"7" 1.0 0 -13840069 true "" ""
"8" 1.0 0 -14835848 true "" ""
"9" 1.0 0 -11221820 true "" ""
"10" 1.0 0 -13791810 true "" ""
"11" 1.0 0 -13345367 true "" ""
"12" 1.0 0 -8630108 true "" ""
"13" 1.0 0 -5825686 true "" ""
"14" 1.0 0 -2064490 true "" ""
"15" 1.0 0 -16777216 true "" ""
"16" 1.0 0 -16777216 true "" ""
"17" 1.0 0 -16777216 true "" ""
"18" 1.0 0 -16777216 true "" ""
"19" 1.0 0 -16777216 true "" ""
"20" 1.0 0 -16777216 true "" ""

BUTTON
1053
613
1124
646
rescale
set-current-plot \"prices\"\nlet pricess ([price] of products)\nset-plot-y-range (round-to-digits ((min pricess) - 0.015625) 3) (round-to-digits ((max pricess) + 0.005625) 3)
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
964
11
1164
161
share
time
share of adopters
0.0
10.0
0.0
0.3
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""
"1" 1.0 0 -7500403 true "" ""
"2" 1.0 0 -2674135 true "" ""
"3" 1.0 0 -955883 true "" ""
"4" 1.0 0 -6459832 true "" ""
"5" 1.0 0 -1184463 true "" ""
"6" 1.0 0 -10899396 true "" ""
"7" 1.0 0 -13840069 true "" ""
"8" 1.0 0 -14835848 true "" ""
"9" 1.0 0 -11221820 true "" ""
"10" 1.0 0 -13791810 true "" ""

PLOT
964
164
1164
314
Agents per product
products
# agents
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" ""

PLOT
757
163
957
313
overall-adopters
time
#
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

MONITOR
974
683
1031
728
NIL
ticks
2
1
11

SLIDER
194
704
366
737
alphad
alphad
0
5
10000.0
0.5
1
NIL
HORIZONTAL

SLIDER
372
704
544
737
betad
betad
0
5
10000.0
0.5
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This section could give a general understanding of what the model is trying to show or explain.

## HOW IT WORKS

This section could explain what rules the agents use to create the overall behavior of the model.

## HOW TO USE IT

This section could explain how to use the model, including a description of each of the items in the interface tab.

## THINGS TO NOTICE

This section could give some ideas of things for the user to notice while running the model.

## THINGS TO TRY

This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.

## EXTENDING THE MODEL

This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.

## NETLOGO FEATURES

This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.

## RELATED MODELS

This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.

## CREDITS AND REFERENCES

This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="20120202-p10runs1" repetitions="1" runMetricsEveryStep="true">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>[n-of-adopters] of products</metric>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.1" last="1"/>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vfm-growth-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;grid 4 nbrs&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="0.11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p10run10" repetitions="10" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>sum [n-of-adopters] of products</metric>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vfm-growth-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;grid 4 nbrs&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="0.11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run1" repetitions="1" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>first [n-of-adopters] of products</metric>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.1" last="1"/>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vfm-growth-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;grid 4 nbrs&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="0.11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run10" repetitions="20" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.02" last="1"/>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <steppedValueSet variable="vfm-growth-rate" first="0" step="0.05" last="0.35"/>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;grid 4 nbrs&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p10run1" repetitions="1" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>sum [n-of-adopters] of products</metric>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vfm-growth-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;grid 4 nbrs&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="0.11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20120203-p1run1" repetitions="1" runMetricsEveryStep="true">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>first [n-of-adopters] of products</metric>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.1" last="1"/>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vfm-growth-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;grid 4 nbrs&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="0.11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p2run10" repetitions="10" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>sum [n-of-adopters] of products</metric>
    <metric>first [n-of-adopters] of products</metric>
    <metric>last [n-of-adopters] of products</metric>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vfm-growth-rate">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;grid 4 nbrs&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="0.11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run50grid4learning" repetitions="50" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;grid 4 nbrs&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vfm-growth-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-vfm-index">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;ring&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run10ring" repetitions="10" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="vfm-growth-rate" first="0" step="0.05" last="0.35"/>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;ring&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run10ring8" repetitions="10" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="vfm-growth-rate" first="0" step="0.05" last="0.35"/>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;ring&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run10RandomNtw" repetitions="10" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="vfm-growth-rate" first="0" step="0.05" last="0.35"/>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run10RandomNtw2" repetitions="10" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vfm-growth-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="5000"/>
      <value value="10000"/>
      <value value="15000"/>
      <value value="20000"/>
      <value value="25000"/>
      <value value="30000"/>
      <value value="35000"/>
      <value value="40000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run10SW" repetitions="10" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0.001"/>
      <value value="0.01"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vfm-growth-rate">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-vfm-index" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;Watts-Strogatz&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run10ring4learning" repetitions="10" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;ring&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run10random4learning" repetitions="10" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;Watts-Strogatz&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run50grid4seeds" repetitions="50" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;grid 4 nbrs&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run10PA" repetitions="10" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="19997"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;preferential attachment&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run20PA2learning" repetitions="20" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="19997"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;preferential attachment&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run20PA2seeds" repetitions="20" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="19997"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;preferential attachment&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="p1run50grid4learningDual" repetitions="50" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="learning-coefficient" first="0" step="0.02" last="0.4"/>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-price">
      <value value="0.6"/>
      <value value="0.8"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;grid 4 nbrs&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130410WS" repetitions="20" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>ticks</metric>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
      <value value="0.001"/>
      <value value="0.01"/>
      <value value="0.1"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-price">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;Watts-Strogatz&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20131017SW" repetitions="10" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="alpha">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
      <value value="0.01"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="lambda">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demand">
      <value value="&quot;gamma&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;Watts-Strogatz&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20131021SW" repetitions="20" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>sum [n-of-adopters] of products</metric>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
      <value value="0.01"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="betad">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alphad">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="beta">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;Watts-Strogatz&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20140413SW" repetitions="20" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>sum [n-of-adopters] of products</metric>
    <metric>ticks</metric>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
      <value value="0.01"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="betad">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alphad">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="beta">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;Watts-Strogatz&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20140415SW" repetitions="20" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>sum [n-of-adopters] of products</metric>
    <metric>ticks</metric>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
      <value value="0.01"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="betad">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alphad">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="beta">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;Watts-Strogatz&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20141110SW" repetitions="20" runMetricsEveryStep="false">
    <setup>startup</setup>
    <go>go</go>
    <exitCondition>not any? (consumers with [product-bought-in-previous-time-step?])</exitCondition>
    <metric>sum [n-of-adopters] of products</metric>
    <metric>ticks</metric>
    <enumeratedValueSet variable="p-rewiring">
      <value value="0"/>
      <value value="0.01"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid-radius">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="betad">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="give-it-for-free?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="attention-list-mode">
      <value value="&quot;products just bought only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-links">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-exogenous-buy">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alphad">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-initial-offers">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-price" first="0" step="0.05" last="1"/>
    <enumeratedValueSet variable="beta">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-consumers">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tau">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-coefficient">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="accessibility-steps">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-of-products">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-structure">
      <value value="&quot;Watts-Strogatz&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pref-attachment-links">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
